import { useState, useCallback, useEffect } from 'react';

const TRIGGER_EVENT = 'smarthr-ui:remote-dialog-trigger-dispatch';
function useRemoteTrigger({ onClickClose: orgOnClickClose, onPressEscape: orgOnPressEscape, onToggle, onOpen, onClose, id, }) {
    const [isOpen, setIsOpen] = useState(false);
    const onClickClose = useCallback(() => {
        if (orgOnClickClose) {
            return orgOnClickClose(() => {
                setIsOpen(false);
            });
        }
        setIsOpen(false);
    }, [orgOnClickClose]);
    const onPressEscape = useCallback(() => {
        if (orgOnPressEscape) {
            return orgOnPressEscape(() => {
                setIsOpen(false);
            });
        }
        setIsOpen(false);
    }, [orgOnPressEscape]);
    useEffect(() => {
        const handler = ((e) => {
            if (id === e.detail.id) {
                setIsOpen(true);
            }
        });
        document.addEventListener(TRIGGER_EVENT, handler);
        return () => {
            document.removeEventListener(TRIGGER_EVENT, handler);
        };
    }, [id]);
    useEffect(() => {
        onToggle?.(isOpen);
        if (isOpen) {
            onOpen?.();
        }
        else {
            onClose?.();
        }
        // HINT: 再レンダリング際にhookを利用していないonToggleなどが渡されると意図せず発火してしまう場合がありえるため
        // onToggle, onOpen, onClose を depsに含めていません
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [isOpen]);
    return {
        isOpen,
        onClickClose,
        onPressEscape,
    };
}

export { TRIGGER_EVENT, useRemoteTrigger };
//# sourceMappingURL=useRemoteTrigger.js.map
