import { jsx, jsxs } from 'react/jsx-runtime';
import { memo, useMemo } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.11.21_@types_node@20.17.30_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import '../Button/Button.js';
import '../Button/AnchorButton.js';
import { UnstyledButton } from '../Button/UnstyledButton.js';
import { FaSortUpIcon, FaSortDownIcon } from '../Icon/Icon.js';
import '../Icon/generateIcon.js';
import { VisuallyHiddenText } from '../VisuallyHiddenText/VisuallyHiddenText.js';
import { reelShadowClassNameGenerator } from './reelShadowStyle.js';

const SORT_DIRECTION_LABEL = {
    asc: '昇順',
    desc: '降順',
    none: '並び替えなし',
};
const classNameGenerator = ce({
    base: [
        'smarthr-ui-Th',
        'shr-border-solid shr-border-0 shr-px-1 shr-py-0.75 shr-text-left shr-align-middle shr-text-sm shr-font-bold shr-leading-tight shr-text-black',
        [
            '[.shr-table-border-vertical_&+&]:shr-border-l',
            '[.shr-table-border-vertical_&+&]:shr-border-l-default',
        ],
        'aria-[sort]:shr-cursor-pointer',
        'hover:aria-[sort]:shr-bg-head-darken',
        '[&:has(:focus-visible)]:aria-[sort]:shr-focus-indicator',
        '[&[aria-sort=none]_.smarthr-ui-Icon]:forced-colors:shr-fill-[GrayText]',
        '[&[aria-sort=ascending]_.smarthr-ui-Icon:first-of-type]:forced-colors:shr-fill-[CanvasText] [&[aria-sort=ascending]_.smarthr-ui-Icon:last-of-type]:forced-colors:shr-fill-[GrayText]',
        '[&[aria-sort=descending]_.smarthr-ui-Icon:first-of-type]:forced-colors:shr-fill-[GrayText] [&[aria-sort=descending]_.smarthr-ui-Icon:last-of-type]:forced-colors:shr-fill-[CanvasText]',
    ],
    variants: {
        align: {
            left: '',
            right: 'shr-text-right',
        },
        vAlign: {
            middle: '',
            baseline: 'shr-align-baseline',
            bottom: 'shr-align-bottom',
        },
    },
    defaultVariants: {
        align: 'left',
        vAlign: 'middle',
    },
});
const convertContentWidth = (contentWidth) => {
    if (typeof contentWidth === 'number') {
        // Th は fontSize.S のため、rem で指定する
        return `${contentWidth}rem`;
    }
    return contentWidth;
};
const Th = memo(({ children, sort, onSort, decorators, align, vAlign, fixed, contentWidth, className, style, ...props }) => {
    const actualClassName = useMemo(() => {
        const base = classNameGenerator({ className, align, vAlign });
        if (!fixed) {
            return base;
        }
        const shadow = reelShadowClassNameGenerator({ showShadow: false, direction: fixed });
        return `${base} ${shadow}`;
    }, [align, className, fixed, vAlign]);
    const actualStyle = useMemo(() => ({
        ...style,
        width: convertContentWidth(contentWidth),
    }), [style, contentWidth]);
    const sortLabel = useMemo(() => sort &&
        (decorators?.sortDirectionIconAlt?.(SORT_DIRECTION_LABEL[sort], { sort }) ||
            SORT_DIRECTION_LABEL[sort]), [decorators, sort]);
    const ariaSort = useMemo(() => (sort ? (sort === 'none' ? 'none' : `${sort}ending`) : undefined), [sort]);
    return (jsx("th", { ...props, "aria-sort": ariaSort, "data-fixed": fixed, className: actualClassName, style: actualStyle, children: sort ? (jsx(MemoizedSortButton, { align: align, onSort: onSort, sortLabel: sortLabel, children: children })) : (children) }));
});
const sortButtonClassNameGenerator = ce({
    base: '-shr-mx-1 -shr-my-0.75 shr-inline-flex shr-w-full shr-gap-x-0.5 shr-px-1 shr-py-0.75 shr-font-bold shr-items-center shr-justify-between',
    variants: {
        align: {
            left: '',
            right: 'shr-justify-end',
        },
    },
});
const MemoizedSortButton = memo(({ align, onSort, sortLabel, children }) => {
    const className = useMemo(() => sortButtonClassNameGenerator({ align }), [align]);
    return (jsxs(UnstyledButton, { onClick: onSort, className: className, children: [children, jsx(SortIcon, {}), jsx(VisuallyHiddenText, { children: sortLabel })] }));
});
const sortIconClassNameGenerator = ce({
    slots: {
        wrapper: 'smarthr-ui-Icon-extended shr-relative shr-w-1 shr-h-1',
        upIcon: [
            'shr-absolute shr-top-0 shr-left-0',
            'shr-text-base',
            '[[aria-sort="none"]_&]:shr-text-disabled',
            '[[aria-sort="ascending"]_&]:shr-text-black',
            '[[aria-sort="descending"]_&]:shr-text-disabled',
        ],
        downIcon: [
            'shr-absolute shr-top-0 shr-left-0',
            'shr-text-base',
            '[[aria-sort="none"]_&]:shr-text-disabled',
            '[[aria-sort="ascending"]_&]:shr-text-disabled',
            '[[aria-sort="descending"]_&]:shr-text-black',
        ],
    },
});
const SortIcon = memo(() => {
    const classNames = useMemo(() => {
        const { wrapper, upIcon, downIcon } = sortIconClassNameGenerator();
        return {
            wrapper: wrapper(),
            upIcon: upIcon(),
            downIcon: downIcon(),
        };
    }, []);
    return (jsxs("span", { className: classNames.wrapper, children: [jsx(FaSortUpIcon, { className: classNames.upIcon }), jsx(FaSortDownIcon, { className: classNames.downIcon })] }));
});

export { Th };
//# sourceMappingURL=Th.js.map
