import { jsx, jsxs } from 'react/jsx-runtime';
import { forwardRef, useMemo } from 'react';
import { tv as ce } from './../../vendor/.pnpm/tailwind-variants@0.3.1_tailwindcss@3.4.17_ts-node@10.9.2_@swc_core@1.11.21_@types_node@20.17.30_typescript@5.8.3__/vendor/tailwind-variants/dist/index.js';
import { useDecorators } from '../../hooks/useDecorators.js';
import { Balloon } from '../Balloon/Balloon.js';
import { Checkbox } from '../Checkbox/Checkbox.js';
import { Th } from './Th.js';

const DECORATOR_DEFAULT_TEXTS = {
    checkAllInvisibleLabel: 'すべての項目を選択/解除',
    checkColumnName: '選択',
};
const classNameGenerator = ce({
    slots: {
        inner: [
            'shr-group/label',
            'shr-relative shr-flex shr-justify-center shr-py-0.75 shr-px-1',
            '[&:not(:has([disabled]))]:shr-cursor-pointer',
        ],
        wrapper: 'shr-p-0 shr-w-[theme(fontSize.base)]',
        checkbox: ['shr-leading-[0]', '[&>span]:shr-translate-y-[unset]'],
        balloon: [
            // 位置はセルの真ん中(50%)+checkboxの幅の半分(8px)+outlineの幅(4px)+Balloonの矢印の幅(5px), sr-onlyで隠す
            'shr-absolute shr-left-[calc(50%+(theme(fontSize.base)/2)+4px+5px)] shr-sr-only',
            // labelの中の要素に hover or focus-visible がある時のスタイル。shr-absoluteはshr-not-sr-onlyのpositionをabsoluteに上書きしている
            'group-has-[:hover,:focus-visible]/label:shr-not-sr-only group-has-[:hover,:focus-visible]/label:shr-absolute group-has-[:hover,:focus-visible]/label:shr-whitespace-nowrap',
        ],
    },
});
const ThCheckbox = forwardRef(({ vAlign, decorators, className, ...others }, ref) => {
    const classNames = useMemo(() => {
        const { wrapper, inner, balloon, checkbox } = classNameGenerator();
        return {
            wrapper: wrapper({ className }),
            inner: inner(),
            balloon: balloon(),
            checkbox: checkbox(),
        };
    }, [className]);
    const decorated = useDecorators(DECORATOR_DEFAULT_TEXTS, decorators);
    return (
    // Th に必要な属性やイベントは不要
    jsx(Th, { vAlign: vAlign, className: classNames.wrapper, "aria-label": decorated.checkColumnName, children: jsxs("label", { className: classNames.inner, children: [jsx(Balloon, { as: "span", horizontal: "left", vertical: "middle", className: classNames.balloon, children: jsx("span", { className: "shr-p-0.5 shr-block", children: decorated.checkAllInvisibleLabel }) }), jsx(Checkbox, { ...others, ref: ref, className: classNames.checkbox })] }) }));
});

export { ThCheckbox };
//# sourceMappingURL=ThCheckbox.js.map
