"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.DropZone = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Button_1 = require("../Button");
const Icon_1 = require("../Icon");
const dropZone = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: [
            'smarthr-ui-DropZone',
            'shr-border-shorthand shr-flex shr-flex-col shr-items-center shr-justify-center shr-bg-column shr-p-2.5',
        ],
        input: 'shr-hidden',
    },
    variants: {
        filesDraggedOver: {
            true: {
                wrapper: 'shr-border-main',
            },
            false: {
                wrapper: 'shr-border-dashed',
            },
        },
    },
});
const SELECT_BUTTON_LABEL = 'ファイルを選択';
const overrideEventDefault = (e) => {
    e.preventDefault();
    e.stopPropagation();
};
exports.DropZone = (0, react_1.forwardRef)(({ children, onSelectFiles, multiple = true, decorators, ...props }, ref) => {
    const fileRef = (0, react_1.useRef)(null);
    const [filesDraggedOver, setFilesDraggedOver] = (0, react_1.useState)(false);
    const { wrapper, input } = (0, react_1.useMemo)(() => dropZone({ filesDraggedOver }), [filesDraggedOver]);
    (0, react_1.useImperativeHandle)(ref, () => fileRef.current);
    const onDrop = (0, react_1.useCallback)((e) => {
        overrideEventDefault(e);
        setFilesDraggedOver(false);
        onSelectFiles(e, e.dataTransfer.files);
        if (fileRef.current) {
            fileRef.current.files = e.dataTransfer.files;
        }
    }, [setFilesDraggedOver, onSelectFiles]);
    const onDragOver = (0, react_1.useCallback)((e) => {
        overrideEventDefault(e);
        setFilesDraggedOver(true);
    }, [setFilesDraggedOver]);
    const onDragLeave = (0, react_1.useCallback)(() => {
        setFilesDraggedOver(false);
    }, [setFilesDraggedOver]);
    const onChange = (0, react_1.useCallback)((e) => {
        onSelectFiles(e, e.target.files);
    }, [onSelectFiles]);
    const onClickButton = (0, react_1.useCallback)(() => {
        fileRef.current.click();
    }, []);
    return (
    // eslint-disable-next-line jsx-a11y/no-static-element-interactions
    (0, jsx_runtime_1.jsxs)("div", { onDrop: onDrop, onDragOver: onDragOver, onDragLeave: onDragLeave, className: wrapper(), children: [children, (0, jsx_runtime_1.jsx)(SelectButton, { decorators: decorators, onClick: onClickButton }), (0, jsx_runtime_1.jsx)("input", { ...props, "data-smarthr-ui-input": "true", ref: fileRef, type: "file", multiple: multiple, onChange: onChange, className: input() })] }));
});
const SelectButton = (0, react_1.memo)(({ onClick, decorators }) => {
    const selectButtonLabel = (0, react_1.useMemo)(() => decorators?.selectButtonLabel?.(SELECT_BUTTON_LABEL) || SELECT_BUTTON_LABEL, [decorators]);
    return ((0, jsx_runtime_1.jsx)(Button_1.Button, { prefix: (0, jsx_runtime_1.jsx)(Icon_1.FaFolderOpenIcon, {}), onClick: onClick, children: selectButtonLabel }));
});
//# sourceMappingURL=DropZone.js.map