"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.Dropdown = exports.DropdownContext = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const usePortal_1 = require("../../hooks/usePortal");
const dropdownHelper_1 = require("./dropdownHelper");
const initialRect = { top: 0, right: 0, bottom: 0, left: 0 };
exports.DropdownContext = (0, react_1.createContext)({
    active: false,
    triggerRect: initialRect,
    triggerElementRef: (0, react_1.createRef)(),
    rootTriggerRef: null,
    onClickTrigger: () => {
        /* noop */
    },
    onClickCloser: () => {
        /* noop */
    },
    DropdownContentRoot: () => null,
    contentId: '',
});
const Dropdown = ({ onOpen, onClose, children }) => {
    const [active, setActive] = (0, react_1.useState)(false);
    const [triggerRect, setTriggerRect] = (0, react_1.useState)(initialRect);
    const { rootTriggerRef } = (0, react_1.useContext)(exports.DropdownContext);
    const { createPortal, portalRoot, isPortalRootMounted, isChildPortal, PortalParentProvider } = (0, usePortal_1.usePortal)();
    const triggerElementRef = (0, react_1.useRef)(null);
    const contentId = (0, react_1.useId)();
    if (portalRoot) {
        portalRoot.setAttribute('id', contentId);
    }
    (0, react_1.useEffect)(() => {
        const onClickBody = (e) => {
            // ignore events from events within DropdownTrigger and DropdownContent
            if (!(0, dropdownHelper_1.isEventFromChild)(e, triggerElementRef.current) && !isChildPortal(e.target)) {
                setActive(false);
            }
        };
        document.body.addEventListener('click', onClickBody, false);
        return () => {
            document.body.removeEventListener('click', onClickBody, false);
        };
    }, [isChildPortal, portalRoot]);
    // This is the root container of a dropdown content located in outside the DOM tree
    const DropdownContentRoot = (0, react_1.useMemo)(() => (props) => (active ? createPortal(props.children) : null), [active, createPortal]);
    // set the displayName explicit for DevTools
    DropdownContentRoot.displayName = 'DropdownContentRoot';
    (0, react_1.useEffect)(() => {
        if (isPortalRootMounted()) {
            ;
            (active ? onOpen : onClose)?.();
        }
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [active]);
    const onClickTrigger = (0, react_1.useCallback)((rect) => {
        setActive((current) => {
            const newActive = !current;
            if (newActive) {
                setTriggerRect(rect);
            }
            return newActive;
        });
    }, []);
    const onClickCloser = (0, react_1.useCallback)(() => {
        setActive(false);
        // return focus to the Trigger
        (0, dropdownHelper_1.getFirstTabbable)(triggerElementRef)?.focus();
    }, []);
    return ((0, jsx_runtime_1.jsx)(PortalParentProvider, { children: (0, jsx_runtime_1.jsx)(exports.DropdownContext.Provider, { value: {
                active,
                triggerRect,
                triggerElementRef,
                rootTriggerRef: rootTriggerRef || triggerElementRef || null,
                onClickTrigger,
                onClickCloser,
                DropdownContentRoot,
                contentId,
            }, children: children }) }));
};
exports.Dropdown = Dropdown;
//# sourceMappingURL=Dropdown.js.map