"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.FlashMessage = exports.roles = exports.messageTypes = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Button_1 = require("../Button");
const Icon_1 = require("../Icon");
const ResponseMessage_1 = require("../ResponseMessage");
exports.messageTypes = ['success', 'info', 'warning', 'error'];
exports.roles = ['alert', 'status'];
const REMOVE_DELAY = 8000;
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: [
            'smarthr-ui-FlashMessage',
            'shr-border-shorthand shr-fixed shr-bottom-0.5 shr-left-0.5 shr-z-flash-message shr-flex shr-items-center shr-gap-0.5 shr-rounded-m shr-bg-white shr-p-1 shr-shadow-layer-4',
            '[&_.smarthr-ui-Icon-withText]:-shr-my-0.25 [&_.smarthr-ui-Icon-withText]:shr-grow',
            /* Icon + margin + 8文字 + margin + Button(border + padding + fontSize) */
            'shr-min-w-[calc(1em+theme(spacing[0.5])+8em+theme(spacing[0.5])+(theme(borderWidth.DEFAULT)*2)+(theme(spacing[0.5])*2)+theme(fontSize.sm))]',
        ],
        responseMessage: ['smarthr-ui-FlashMessage-icon', ''],
        closeButton: ['smarthr-ui-FlashMessage-button', '-shr-my-0.5 -shr-mr-0.5'],
    },
    variants: {
        animation: {
            bounce: {
                wrapper: [
                    'shr-animate-[flash-message-bounce_1s_0s_both]',
                    'motion-reduce:shr-animate-none',
                ],
            },
            none: {},
        },
    },
});
/**
 * @deprecated `FlashMessage` は気づきにくいため、安易な使用はお勧めしません。`NotificationBar` や `Dialog` の使用を検討してください。
 */
const FlashMessage = ({ visible, ...rest }) => visible ? (0, jsx_runtime_1.jsx)(ActualFlashMessage, { ...rest }) : null;
exports.FlashMessage = FlashMessage;
const ActualFlashMessage = ({ type, text, animation = 'bounce', role = 'alert', className, onClose, autoClose = true, ...rest }) => {
    (0, react_1.useEffect)(() => {
        if (!autoClose) {
            return;
        }
        const timerId = setTimeout(onClose, REMOVE_DELAY);
        return () => {
            clearTimeout(timerId);
        };
    }, [autoClose, onClose]);
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper, responseMessage, closeButton } = classNameGenerator();
        return {
            wrapper: wrapper({ animation, className }),
            responseMessage: responseMessage(),
            closeButton: closeButton(),
        };
    }, [animation, className]);
    return ((0, jsx_runtime_1.jsxs)("div", { ...rest, role: role, className: classNames.wrapper, children: [(0, jsx_runtime_1.jsx)(ResponseMessage_1.ResponseMessage, { type: type, iconGap: 0.5, className: classNames.responseMessage, children: text }), (0, jsx_runtime_1.jsx)(Button_1.Button, { onClick: onClose, size: "s", className: classNames.closeButton, children: (0, jsx_runtime_1.jsx)(Icon_1.FaXmarkIcon, { alt: "\u9589\u3058\u308B" }) })] }));
};
//# sourceMappingURL=FlashMessage.js.map