"use strict";
'use client';
Object.defineProperty(exports, "__esModule", { value: true });
exports.RadioButtonPanel = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Base_1 = require("../Base");
const RadioButton_1 = require("../RadioButton");
const NONE_ROLE_TAG_REGEX = /^(div|span)$/;
const classNameGenerator = (0, tailwind_variants_1.tv)({
    base: [
        'smarthr-ui-RadioButtonPanel',
        'shr-border-shorthand shr-list-none shr-shadow-none',
        // なぜか :has が動作しないので重ねて書いている
        'has-[:focus-visible]:shr-focus-indicator [&:has(:focus-visible)]:shr-focus-indicator',
        '[&_.smarthr-ui-RadioButton-radioButton:focus-visible_+_span]:shr-shadow-none',
        '[&_.smarthr-ui-RadioButton-label]:shr-ms-0.75',
        'shr-cursor-pointer has-[:not(:disabled)]:[&_.smarthr-ui-RadioButton-label]:shr-cursor-pointer',
        'has-[:disabled]:shr-cursor-default has-[:disabled]:[&_.smarthr-ui-RadioButton-label]:shr-cursor-default',
    ],
});
const RadioButtonPanel = ({ onClick, as, className, ...props }) => {
    const actualClassName = (0, react_1.useMemo)(() => classNameGenerator({ className }), [className]);
    const role = (0, react_1.useMemo)(() => (typeof as === 'string' && NONE_ROLE_TAG_REGEX.test(as) ? 'presentation' : undefined), [as]);
    // 外側の装飾を押しても内側のラジオボタンが押せるようにする
    const innerRef = (0, react_1.useRef)(null);
    const handleOuterClick = (0, react_1.useCallback)(() => {
        innerRef.current?.click();
    }, []);
    return (
    // eslint-disable-next-line smarthr/a11y-delegate-element-has-role-presentation
    (0, jsx_runtime_1.jsx)(Base_1.Base, { padding: 1, role: role, onClick: handleOuterClick, as: as, className: actualClassName, children: (0, jsx_runtime_1.jsx)(RadioButton_1.RadioButton, { ...props, ref: innerRef }) }));
};
exports.RadioButtonPanel = RadioButtonPanel;
//# sourceMappingURL=RadioButtonPanel.js.map