"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VerticalStepItem = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Heading_1 = require("../Heading");
const SectioningContent_1 = require("../SectioningContent/SectioningContent");
const StepCounter_1 = require("./StepCounter");
const classNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: 'shr-group/stepItem',
        headingWrapper: 'shr-flex shr-items-center shr-gap-1',
        heading: 'shr-inline-block',
        body: [
            // body > (:before + inner) という構造
            'shr-flex',
            // body の before 疑似要素がステップを繋ぐ線
            'before:shr-block before:shr-content-[""] before:shr-relative before:shr-mx-1 before:shr-bg-border before:shr-w-[theme(borderWidth.2)]',
            // 最後のステップの線を消す
            'group-last/stepItem:before:shr-bg-transparent',
            'forced-colors:before:shr-bg-[ButtonBorder]',
        ],
        inner: 'shr-grow shr-ms-1 shr-pt-0.5 shr-pb-1.5',
    },
    variants: {
        status: {
            completed: {
                body: ['before:shr-bg-main', 'forced-colors:before:shr-bg-[Highlight]'],
            },
            closed: {},
        },
        current: {
            true: {
                heading: 'shr-font-bold',
            },
            false: {},
        },
    },
    compoundVariants: [
        {
            status: ['completed', 'closed'],
            current: false,
            className: {
                heading: 'shr-text-grey',
            },
        },
    ],
});
const VerticalStepItem = ({ stepNumber, label, status, children, current }) => {
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper, headingWrapper, heading, body, inner } = classNameGenerator({
            status: typeof status === 'object' ? status.type : status,
            current,
        });
        return {
            wrapper: wrapper(),
            headingWrapper: headingWrapper(),
            heading: heading(),
            body: body(),
            inner: inner(),
        };
    }, [current, status]);
    return ((0, jsx_runtime_1.jsx)("li", { "aria-current": current ? 'step' : undefined, className: classNames.wrapper, children: (0, jsx_runtime_1.jsxs)(SectioningContent_1.Section, { children: [(0, jsx_runtime_1.jsx)(StepHeading, { status: status, current: current, stepNumber: stepNumber, className: classNames.headingWrapper, headingClassName: classNames.heading, children: label }), (0, jsx_runtime_1.jsx)("div", { className: classNames.body, children: (0, jsx_runtime_1.jsx)("div", { className: classNames.inner, children: children }) })] }) }));
};
exports.VerticalStepItem = VerticalStepItem;
const StepHeading = (0, react_1.memo)(({ status, current, stepNumber, children, className, headingClassName }) => ((0, jsx_runtime_1.jsxs)("div", { className: className, children: [(0, jsx_runtime_1.jsx)(StepCounter_1.StepCounter, { status: status, current: current, stepNumber: stepNumber }), (0, jsx_runtime_1.jsx)(Heading_1.Heading, { type: "sectionTitle", className: headingClassName, children: children })] })));
//# sourceMappingURL=VerticalStepItem.js.map