"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Th = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tailwind_variants_1 = require("tailwind-variants");
const Button_1 = require("../Button");
const Icon_1 = require("../Icon");
const VisuallyHiddenText_1 = require("../VisuallyHiddenText");
const reelShadowStyle_1 = require("./reelShadowStyle");
const SORT_DIRECTION_LABEL = {
    asc: '昇順',
    desc: '降順',
    none: '並び替えなし',
};
const classNameGenerator = (0, tailwind_variants_1.tv)({
    base: [
        'smarthr-ui-Th',
        'shr-border-solid shr-border-0 shr-px-1 shr-py-0.75 shr-text-left shr-align-middle shr-text-sm shr-font-bold shr-leading-tight shr-text-black',
        [
            '[.shr-table-border-vertical_&+&]:shr-border-l',
            '[.shr-table-border-vertical_&+&]:shr-border-l-default',
        ],
        'aria-[sort]:shr-cursor-pointer',
        'hover:aria-[sort]:shr-bg-head-darken',
        '[&:has(:focus-visible)]:aria-[sort]:shr-focus-indicator',
        '[&[aria-sort=none]_.smarthr-ui-Icon]:forced-colors:shr-fill-[GrayText]',
        '[&[aria-sort=ascending]_.smarthr-ui-Icon:first-of-type]:forced-colors:shr-fill-[CanvasText] [&[aria-sort=ascending]_.smarthr-ui-Icon:last-of-type]:forced-colors:shr-fill-[GrayText]',
        '[&[aria-sort=descending]_.smarthr-ui-Icon:first-of-type]:forced-colors:shr-fill-[GrayText] [&[aria-sort=descending]_.smarthr-ui-Icon:last-of-type]:forced-colors:shr-fill-[CanvasText]',
    ],
    variants: {
        align: {
            left: '',
            right: 'shr-text-right',
        },
        vAlign: {
            middle: '',
            baseline: 'shr-align-baseline',
            bottom: 'shr-align-bottom',
        },
    },
    defaultVariants: {
        align: 'left',
        vAlign: 'middle',
    },
});
const convertContentWidth = (contentWidth) => {
    if (typeof contentWidth === 'number') {
        // Th は fontSize.S のため、rem で指定する
        return `${contentWidth}rem`;
    }
    return contentWidth;
};
exports.Th = (0, react_1.memo)(({ children, sort, onSort, decorators, align, vAlign, fixed, contentWidth, className, style, ...props }) => {
    const actualClassName = (0, react_1.useMemo)(() => {
        const base = classNameGenerator({ className, align, vAlign });
        if (!fixed) {
            return base;
        }
        const shadow = (0, reelShadowStyle_1.reelShadowClassNameGenerator)({ showShadow: false, direction: fixed });
        return `${base} ${shadow}`;
    }, [align, className, fixed, vAlign]);
    const actualStyle = (0, react_1.useMemo)(() => ({
        ...style,
        width: convertContentWidth(contentWidth),
    }), [style, contentWidth]);
    const sortLabel = (0, react_1.useMemo)(() => sort &&
        (decorators?.sortDirectionIconAlt?.(SORT_DIRECTION_LABEL[sort], { sort }) ||
            SORT_DIRECTION_LABEL[sort]), [decorators, sort]);
    const ariaSort = (0, react_1.useMemo)(() => (sort ? (sort === 'none' ? 'none' : `${sort}ending`) : undefined), [sort]);
    return ((0, jsx_runtime_1.jsx)("th", { ...props, "aria-sort": ariaSort, "data-fixed": fixed, className: actualClassName, style: actualStyle, children: sort ? ((0, jsx_runtime_1.jsx)(MemoizedSortButton, { align: align, onSort: onSort, sortLabel: sortLabel, children: children })) : (children) }));
});
const sortButtonClassNameGenerator = (0, tailwind_variants_1.tv)({
    base: '-shr-mx-1 -shr-my-0.75 shr-inline-flex shr-w-full shr-gap-x-0.5 shr-px-1 shr-py-0.75 shr-font-bold shr-items-center shr-justify-between',
    variants: {
        align: {
            left: '',
            right: 'shr-justify-end',
        },
    },
});
const MemoizedSortButton = (0, react_1.memo)(({ align, onSort, sortLabel, children }) => {
    const className = (0, react_1.useMemo)(() => sortButtonClassNameGenerator({ align }), [align]);
    return ((0, jsx_runtime_1.jsxs)(Button_1.UnstyledButton, { onClick: onSort, className: className, children: [children, (0, jsx_runtime_1.jsx)(SortIcon, {}), (0, jsx_runtime_1.jsx)(VisuallyHiddenText_1.VisuallyHiddenText, { children: sortLabel })] }));
});
const sortIconClassNameGenerator = (0, tailwind_variants_1.tv)({
    slots: {
        wrapper: 'smarthr-ui-Icon-extended shr-relative shr-w-1 shr-h-1',
        upIcon: [
            'shr-absolute shr-top-0 shr-left-0',
            'shr-text-base',
            '[[aria-sort="none"]_&]:shr-text-disabled',
            '[[aria-sort="ascending"]_&]:shr-text-black',
            '[[aria-sort="descending"]_&]:shr-text-disabled',
        ],
        downIcon: [
            'shr-absolute shr-top-0 shr-left-0',
            'shr-text-base',
            '[[aria-sort="none"]_&]:shr-text-disabled',
            '[[aria-sort="ascending"]_&]:shr-text-disabled',
            '[[aria-sort="descending"]_&]:shr-text-black',
        ],
    },
});
const SortIcon = (0, react_1.memo)(() => {
    const classNames = (0, react_1.useMemo)(() => {
        const { wrapper, upIcon, downIcon } = sortIconClassNameGenerator();
        return {
            wrapper: wrapper(),
            upIcon: upIcon(),
            downIcon: downIcon(),
        };
    }, []);
    return ((0, jsx_runtime_1.jsxs)("span", { className: classNames.wrapper, children: [(0, jsx_runtime_1.jsx)(Icon_1.FaSortUpIcon, { className: classNames.upIcon }), (0, jsx_runtime_1.jsx)(Icon_1.FaSortDownIcon, { className: classNames.downIcon })] }));
});
//# sourceMappingURL=Th.js.map