"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useReelCells = void 0;
const react_1 = require("react");
const TR_SELECTOR = 'table tr';
const FIXED_LEFT_SELECTOR = '[data-fixed="left"]';
const FIXED_RIGHT_SELECTOR = '[data-fixed="right"]';
const HAS_FIXED_SELECTOR = `${TR_SELECTOR} ${FIXED_LEFT_SELECTOR},${TR_SELECTOR} ${FIXED_RIGHT_SELECTOR}`;
const useReelCells = () => {
    const tableWrapperRef = (0, react_1.useRef)(null);
    const [showShadow, setShowShadow] = (0, react_1.useState)(false);
    (0, react_1.useEffect)(() => {
        const currentRef = tableWrapperRef.current;
        if (!currentRef) {
            return;
        }
        let cellCleans = [];
        const allClean = () => {
            cellCleans.forEach((clean) => clean());
            cellCleans = [];
        };
        const handleScroll = () => {
            if (!currentRef.querySelector(HAS_FIXED_SELECTOR)) {
                return;
            }
            let isVisible = false;
            const commonAction = (cells, direction, visible) => {
                allClean();
                const action = () => {
                    let position = 0;
                    cells.forEach((cell, index) => {
                        if (cell.classList.toggle('fixed', visible)) {
                            isVisible = true;
                            cell.style[direction] = `${position}px`;
                            cell.style.zIndex = (index + 1).toString();
                            position += cell.offsetWidth;
                        }
                    });
                };
                action();
                const observer = new ResizeObserver(action);
                cells.forEach((cell) => {
                    observer.observe(cell);
                });
                cellCleans.push(() => {
                    cells.forEach((cell) => {
                        observer.unobserve(cell);
                    });
                });
            };
            currentRef.querySelectorAll(TR_SELECTOR).forEach((tr) => {
                const leftCells = tr.querySelectorAll(FIXED_LEFT_SELECTOR);
                const rightCells = Array.from(tr.querySelectorAll(FIXED_RIGHT_SELECTOR)).reverse();
                if (leftCells.length > 0) {
                    commonAction(leftCells, 'left', currentRef.scrollLeft > 0);
                }
                if (rightCells.length > 0) {
                    commonAction(rightCells, 'right', currentRef.scrollLeft < currentRef.scrollWidth - currentRef.clientWidth - 1);
                }
            });
            setShowShadow(isVisible);
        };
        handleScroll();
        currentRef.addEventListener('scroll', handleScroll);
        const observer = new ResizeObserver(handleScroll);
        observer.observe(currentRef);
        return () => {
            currentRef.removeEventListener('scroll', handleScroll);
            observer.unobserve(currentRef);
            allClean();
        };
    }, []);
    return { tableWrapperRef, showShadow };
};
exports.useReelCells = useReelCells;
//# sourceMappingURL=useReelCells.js.map